/*
 * Demonstration: Restaurant Finder
 * in Flash MX 2004 by PhilFlash - http://philflash.inway.fr
 *
 * Initial Release in Flex by Christophe Coenraets
 * http://coenraets.com/viewarticle.jsp?articleId=9
 *
 */

import mx.controls.Button;
import mx.controls.Alert;
import mx.controls.ProgressBar;
import mx.controls.TextArea;
import mx.controls.Label;

import mx.controls.DataGrid;
import mx.data.components.DataSet;
import mx.data.components.XMLConnector;

import mx.data.components.datasetclasses.DataSetError;
import mx.data.to.ValueListIterator;

import ApplicationForm;

class FormSearch extends mx.screens.Form {

	public var restaurant_conn:XMLConnector;
	public var restaurantByArea_conn:XMLConnector;
	public var restaurant_ds:DataSet;
	public var restaurant_dg:DataGrid;
	
	private var map:MovieClip;
	private var selector:MovieClip;
	private var bullet:MovieClip;
	private var loading_bg:MovieClip;
	
	private var urlRestaurantByArea:String;
	
	private var pBarData:ProgressBar;	
	private var dataLoaded:Boolean = false;

	
	// Constructor
	public function FormSearch() {}
	
	// -----  -----
	public function init():Void {
		super.init();
		addEventListener("reveal", onReveal);
		addEventListener("selectionChanged", onSelectionChanged);		
	}

	// -----  -----	
	public function onLoad(obj:Object):Void {
		dataLoaded = false;

		setVisible(true);
		
 		pBarData.setVisible(false);
 		bullet._visible = false;
 		loading_bg._visible = false;
 		
 		// --
		restaurant_conn.addEventListener("status",this);
		restaurant_conn.addEventListener("result",this);
		
		restaurant_dg.addEventListener("change", function(evt:Object) { evt.target._parent.changeRestaurantAction(evt); } );
		restaurant_ds.addEventListener("afterLoaded", function(evt:Object) { evt.target._parent.afterLoadedRestaurantAction(evt); } );

		restaurantByArea_conn.addEventListener("status",this);
		restaurantByArea_conn.addEventListener("result",this);
		
		setupRestaurantGrid();
		
		// -- init selector --
		selector.owner = this;
		selector._x = map._x;
		selector._y = map._y;
		selector.onPress = function() {
			var owner = this.owner;
			var map = owner.map;
			var w:Number = map._x+map._width-this._width;
			var h:Number = map._y+map._height-this._height;
			this.startDrag(false, map._x, map._y, w, h);
		}

		selector.onRelease = function() {
			this.stopDrag();
			var owner = this.owner;
			var map = owner.map;
			var x1 = this._x - map._x;
			var y1 = this._y - map._y;
			var x2 = this._x+this._width - map._x;
			var y2 = this._y+this._height - map._y;
			owner.dispatchEvent({type: "selectionChanged", x1: x1, y1: y1, x2: x2,  y2: y2});
		}
	}
	
	// -----  -----
	public function onReveal(obj:Object):Void {
		if (urlRestaurantByArea == undefined) {
			urlRestaurantByArea = restaurantByArea_conn.URL;
		}
		if (!dataLoaded) {
			getRestaurantList();
		}
	}

	// -----  -----	
	public function setupRestaurantGrid(Void):Void {
		var datagrid:DataGrid = restaurant_dg;
		var newColumn:mx.controls.gridclasses.DataGridColumn;

  		datagrid.editable = false;		
		datagrid.removeAllColumns();
		
  		var totalWidth:Number = 0;
  		
		newColumn = new mx.controls.gridclasses.DataGridColumn("name");
		newColumn.headerText = "Name";
		newColumn.width = 200;
		datagrid.addColumn(newColumn);
		totalWidth += newColumn.width;

		newColumn = new mx.controls.gridclasses.DataGridColumn("city");
		newColumn.headerText = "City";
		newColumn.width = 150;
		datagrid.addColumn(newColumn);		
		totalWidth += newColumn.width;
		
		newColumn = new mx.controls.gridclasses.DataGridColumn("phone");
		newColumn.headerText = "Phone";
		newColumn.width = datagrid.width-totalWidth-18; // 18 is the width of the vertical scroolbar
		datagrid.addColumn(newColumn);
	}


	// -----  -----
 	public function getRestaurantList():Void {
 		enableProgress(true, "Loading...");
		restaurant_conn.trigger();
  	}
  	
 	public function getRestaurantByArea(x1:Number, y1:Number, x2:Number, y2:Number):Void {
 		var newURL = urlRestaurantByArea + "?x1=" + x1 + "&y1="+y1+"&x2=" + x2 + "&y2="+y2;
 		restaurantByArea_conn.URL = newURL;
 		// trace(" URL = " + newURL);
 		enableProgress(true, "Loading...");
		restaurantByArea_conn.trigger();
  	}
  	
 	// ----- Resultats sur  XMLConnector -----
	public function status(stat:Object):Void {
		// Erreur sur code PHP
		if (stat.code != "StatusChange") {
			var error:String = "Application error: " + stat.target._name + "/" + stat.code + "/" + stat.data.faultcode + "/" + stat.data.faultstring;

			errorConnector(error);
		}	

	}
	
	public function result():Void {
		enableProgress(false);
		dataLoaded = true;
	} 	
	
	private function errorConnector(message:String):Void {
		enableProgress(false);
		var alertWindow:Alert = Alert.show(	message, 
										"Application Error                     ", 
										Alert.OK, this);
		alertWindow.startDragging = function() {};
		ApplicationForm.setLocationRelativeTo(alertWindow, null);	
	}

	// -----   -----
	// With this, the first item is selected 
	// (and propage event to show the detail for a restaurant)
	public function afterLoadedRestaurantAction(evt:Object):Void {
		//trace("afterLoadedAction action="+restaurant_ds.selectedIndex);
		doLater(this, "forceRestaurantSelectFirstIndex");
	}

	public function forceRestaurantSelectFirstIndex() {
		//trace(" forceRestaurantSelectFirstIndex ="+restaurant_dg.selectedIndex);
		restaurant_dg.selectedIndex = 0;
		restaurant_dg.dispatchEvent({type:"change"});
	}
	
	// -----   -----
	public function onSelectionChanged(eventObj:Object):Void {
		var x1:Number = eventObj.x1;
		var y1:Number = eventObj.y1;	
		var x2:Number = eventObj.x2;
		var y2:Number = eventObj.y2;
		getRestaurantByArea(x1, y1, x2, y2);
	}
	
	// ----- Action -----
	public function changeRestaurantAction(evt:Object):Void {
		var dataset = restaurant_ds;
  		var currentItem = dataset.currentItem;
  		var t:String = "";
  		if (currentItem != undefined) {
  			var title = replaceString(currentItem.name, "'", "&#39;");
  			var description = replaceString(currentItem.review, "'", "&#39;");
  			var image = currentItem.image;
  			
  			var titleURL = "";
  			titleURL = "<span class='title'>"+title+"</span>";
  			
   			var imageURL = "";
  			if (image == "" || image == "noimage.jpg") {
  				imageURL = "";
  			} else {
  				imageURL = "<p><img src='images/"+image+"' hspace='20'></p><br>";
  			}

    		t = titleURL+"<br>"; 
    		t += "<p>"+currentItem.address+" -  <i>"+currentItem.city+"</i></p>";
    		t += "<p>"+currentItem.phone+"</p><br>"; 
    		t += "<p class='description'>"+description+"</p><br>";
    		t += imageURL;
    		t += "<br><br><br><br><br><br><br><br><br><br>";

  			//trace("x  = ="+currentItem.map_x+" , y = "+currentItem.map_y);
     		(rootForm).formInfo.info_ta.text = t;
    		
    		// -- bullet --
    		bullet._x = map._x+currentItem.map_x;
    		bullet._y = map._y+currentItem.map_y;    
    		if (!bullet.visible) {
    			bullet._visible = true;
    		}

			// -- get review information --
			(rootForm).formInfo["getReview"](currentItem.id);
			
  		} else {
    		(rootForm).formInfo.info_ta.text = "";
  			bullet._visible = false;
  		}

	}

	// -----   -----
	private function enableProgress(enabled:Boolean, label:String):Void {
		if (label == undefined) {
			label = "";
		}
		pBarData.indeterminate = enabled;
		pBarData.label = label;
		pBarData.enabled = enabled;
		pBarData._visible = enabled;
 		loading_bg._visible = enabled;		
		restaurant_dg.enabled = !enabled;
	}

	// -----  -----	
	// replaces the from string to to string and returns the modified 
    function replaceString(mainStr:String, findStr:String, replaceStr:String):String {
		return (mainStr.split(findStr).join(replaceStr));
    }

}
    
